MedlinePlus: Flavorful Green Beans
Description: The seasonings are perfect companions to the green beans.

URL of this page: https://medlineplus.gov/recipes/flavorful-green-beans/

# Flavorful Green Beans

A Heart-Healthy Recipe from the National Heart, Lung, and Blood Institute

Prep time: 10 minutes
Cook time: 40 minutes
Total time: 50 minutes
Number of Servings: 7

The seasonings are perfect companions to the green beans.

### Ingredients

- 2 lb fresh green beans
- 1/2 cup cold water
- Nonstick cooking spray
- 1/3 cup chopped onions
- 4 cloves garlic, chopped
- 1/2 tsp ground black pepper
- 1/2 tsp dried basil
- 1/2 tsp dried oregano

### Directions

1. Rinse green beans and snap off tips.
2. Place green beans in a large pot and add 1/2 cup of cold water.
3. Cook green beans on stovetop over medium heat for 10 minutes.
4. Spray a sauté pan with cooking spray, and sauté the chopped onions and garlic for 5 minutes, or until they are tender and very lightly browned.
5. Add onions, garlic, and black pepper to green beans. Spray the cooking spray over mixture, and cook on medium heat for another 20 minutes or until green beans are tender, but not soft. Stir occasionally.
6. Sprinkle dried basil and oregano over green beans. Mix and serve.

Find more delicious heart-healthy recipes from

## Nutrition Information

7 servings per container
Serving size 1 cup
Amount Per Serving
Calories 40
% Daily Value*
Total Fat 0g
Saturated Fat 0g
Cholesterol 0mg
Sodium 12mg
Total Carbohydrate 9g
Dietary Fiber 4g
Protein 2g
Potassium 179mg
* The % Daily Value (DV) tells you how much a nutrient in a serving of food contributes to a daily diet. 2,000 calories a day is used for general nutrition advice.